#!/usr/bin/env python
from distutils.core import setup

setup(
    name='ffindex',
    version='0.0.1',
    description='ffindex support for Python',
    author='Stefan Seemayer',
    author_email='mail@semicolonsoftware.de',
    license='MIT',
    url='https://github.com/sseemayer/ffindex-python',
    py_modules=['ffindex'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent"
    ]
)
